API Documentation
=================

Atom
^^^^

.. autoclass:: udkm1Dsim.Atom
    :members:

AtomMixed
^^^^^^^^^

.. autoclass:: udkm1Dsim.AtomMixed
    :members:
    
UnitCell
^^^^^^^^

.. autoclass:: udkm1Dsim.UnitCell
    :members:

Structure
^^^^^^^^^

.. autoclass:: udkm1Dsim.Structure
    :members: